<?php
/**
*@Module			PRICE OFFER
*@Version			1.0.0	
*@Author    		One_Man
*@Copyright 		2015 - 2017 PRESTALOGIC.CH	
*@Installation		See PDF Documentation	
*@License			See PDF Documentation
*@Website   		https://prestalogic.ch	
*@Support			info@prestalogic.ch	
*/

class PriceOffer extends Module
{
    public $context;
    public function __construct()
    {
        $this->name = 'priceoffer';
        $this->version = '1.0.1';
        $this->author = 'One Man';
        $this->tab = 'front_office_features';
        $this->need_instance = 0;
        $this->secure_key = Tools::encrypt($this->name);
        $this->bootstrap = true;
        $this->module_key = '03a77232202621a6060cbe124f93f672';
        parent::__construct();
        $this->displayName = $this->l('PRICE OFFER By prestalogic.ch');
        $this->description = $this->l('Allows your customers to negotiate the price of your products');
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
    }
 
    public function install()
    {
        Configuration::updateValue('PRICEOFFER_EMAILS', Configuration::get('PS_SHOP_EMAIL'));
		Configuration::updateValue('PRICEOFFER_QTYZERO', 1);
		Configuration::updateValue('PRICEOFFER_ACTZERO', 0);
		Configuration::updateValue('PRICEOFFER_EXCAT', '');
		Configuration::updateValue('PRICEOFFER_EXPROD', '');
        return (parent::install() && $this->registerHook('displayProductButtons') && $this->registerHook('header'));
    }

    public function uninstall()
    {
        Configuration::deleteByName('PRICEOFFER_EMAILS');
		Configuration::deleteByName('PRICEOFFER_QTYZERO');
		Configuration::deleteByName('PRICEOFFER_ACTZERO');
		Configuration::deleteByName('PRICEOFFER_EXCAT');
		Configuration::deleteByName('PRICEOFFER_EXPROD');
        return (parent::uninstall()&&$this->unregisterHook('header')&&$this->unregisterHook('displayProductButtons'));
    }

    public function hookDisplayProductButtons()
    {
        if (Configuration::get('PS_CATALOG_MODE')) {
            return;
        }
  /* Product informations */
        //$product = new Product((int)Tools::getValue('id_product'), false, $this->context->language->id);
		$product = $this->context->controller->getProduct();
        $image = Product::getCover((int)$product->id);
        $currency = new Currency($this->context->cookie->id_currency);
		$zeroqty = Configuration::get('PRICEOFFER_QTYZERO');
		$zeroact = Configuration::get('PRICEOFFER_ACTZERO');
		$excat = Configuration::get('PRICEOFFER_EXCAT');
		$excatids = explode(',', $excat);
		if (in_array($product->id_category_default, $excatids)) { $cat = 1; } else { $cat = 0; };
		$exprod = Configuration::get('PRICEOFFER_EXPROD');
		$exprodids = explode(',', $exprod);
		if (in_array($product->id, $exprodids)) { $prod = 1; } else { $prod = 0; };
        $this->context->smarty->assign(array(
        'mao_product' => $product,
        'mao_product_cover' => (int)$product->id.'-'.(int)$image['id_image'],
        'mao_secure_key' => $this->secure_key,
        'mao_currency' => $currency,
		'mao_qty' => $zeroqty,
		'mao_act' => $zeroact,
		'mao_excat' => $cat,
		'mao_exprod' => $prod
		
        ));

        return $this->display(__FILE__, '/views/templates/front/priceoffer-extra.tpl');
    }

    public function hookHeader()
    {
        if (Configuration::get('PS_CATALOG_MODE')) {
            return;
        }
        $this->page_name = Dispatcher::getInstance()->getController();
        if ($this->page_name == 'product') {
            $this->context->controller->addCSS($this->_path.'/views/css/priceoffer.css', 'all');
            $this->context->controller->addJS($this->_path.'/views/js/priceoffer.js');
        }
    }
 
    public function getContent()
    {
        $output = '<div class="bootstrap panel">
					<div class="panel-heading">
					<i class="icon-book"></i> '.$this->l('Documentation & Support').'
				</div>
					<img src="'.$this->_path.'/views/img/info.png">
					<a style="float:right;margin-left:5px;" target="_blank" href="https://paypal.me/prestajoie/"><img src="'.$this->_path.'/views/img/paypal.png"></a>
					<a style="float:right;margin-left:5px;" target="_blank" href="https://prestalogic.ch/actus/demande-de-support/"><img src="'.$this->_path.'/views/img/support.png"></a>
					<a style="float:right;margin-left:5px;" target="_blank" href="'.$this->_path.'/docs/terms.pdf"><img src="'.$this->_path.'/views/img/terms.png"></a>
					<a style="float:right;margin-left:5px;" target="_blank" href="https://prestalogic.ch/actus/support/offerprice"><img src="'.$this->_path.'/views/img/install.png"></a>
					<a style="float:right;margin-left:5px;" target="_blank" href="https://prestalogic.ch/29-les-options"><img src="'.$this->_path.'/views/img/more.png"></a>
				</div>';
			/////start
        if (Tools::isSubmit('submit'.$this->name)) {
            $mailers = Tools::getValue('PRICEOFFER_EMAILS');
			$qtyzero = Tools::getValue('PRICEOFFER_QTYZERO');
			$actzero = Tools::getValue('PRICEOFFER_ACTZERO');
			$excat = Tools::getValue('PRICEOFFER_EXCAT');
			$exprod = Tools::getValue('PRICEOFFER_EXPROD');
            if (!$mailers || empty($mailers) || !Validate::isGenericName($mailers) || $qtyzero != 0 && $qtyzero != 1 || $actzero != 0 && $actzero != 1) {
                $output .= $this->displayError($this->l('Invalid Configuration value'));
            } else {
                Configuration::updateValue('PRICEOFFER_EMAILS', $mailers);
				Configuration::updateValue('PRICEOFFER_QTYZERO', (int)($qtyzero));
				Configuration::updateValue('PRICEOFFER_ACTZERO', (int)($actzero));
				Configuration::updateValue('PRICEOFFER_EXCAT', $excat);
				Configuration::updateValue('PRICEOFFER_EXPROD', $exprod);
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
			/////end
        }
        return $output.$this->renderForm();
    }

    public function renderForm()
    {
    // Get default language
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');
    // Init Fields form array
        $fields_form = array(
        'form' => array(
        'legend' => array(
            'title' => $this->l('Settings'),
        ),
        'input' => array(
        array(
        'type' => 'text',
        'label' => $this->l('Recipient e-mail addresses:'),
        'name' => 'PRICEOFFER_EMAILS',
        'desc' => $this->l('Separator comma without a space.').' (first@example.com,two@example.com,tree@example.com)',
        'required' => true
        ),
		///
        array(
        'type' => 'text',
        'label' => $this->l('Excluded categories ID:'),
        'name' => 'PRICEOFFER_EXCAT',
        'desc' => $this->l('Separator comma without a space.').' (2,3,6)',
        'required' => false
        ),
        array(
        'type' => 'text',
        'label' => $this->l('Excluded products ID:'),
        'name' => 'PRICEOFFER_EXPROD',
        'desc' => $this->l('Separator comma without a space.').' (5,34,15,156)',
        'required' => false
        ),
		///
        array(
        'type' => 'switch',
        'label' => $this->l('Show on pages with 0 quantity'),
        'name' => 'PRICEOFFER_QTYZERO',
		'is_bool' => true,
		'values' => array(
						array(
						'id' => 'active_on',
						'value' => 1,
						'label' => $this->l('Enabled')
							),
						array(
						'id' => 'active_off',
						'value' => 0,
						'label' => $this->l('Disabled')
							)
						),
        	),
        array(
        'type' => 'switch',
        'label' => $this->l('Active on pages with 0 quantity'),
        'name' => 'PRICEOFFER_ACTZERO',
		'is_bool' => true,
		'values' => array(
						array(
						'id' => 'active_on',
						'value' => 1,
						'label' => $this->l('Enabled')
							),
						array(
						'id' => 'active_off',
						'value' => 0,
						'label' => $this->l('Disabled')
							)
						),
        	),

        ),
        'submit' => array(
        'title' => $this->l('Save'),
        'class' => 'btn btn-default pull-right'
        ),
        )
        );
        $helper = new HelperForm();
    // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;
    // Language
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;
    // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = false;        // false -> remove toolbar
        $helper->submit_action = 'submit'.$this->name;
    // Load current value
        $helper->fields_value['PRICEOFFER_EMAILS'] = Configuration::get('PRICEOFFER_EMAILS');
        $helper->fields_value['PRICEOFFER_QTYZERO'] = Configuration::get('PRICEOFFER_QTYZERO');
        $helper->fields_value['PRICEOFFER_ACTZERO'] = Configuration::get('PRICEOFFER_ACTZERO');
		$helper->fields_value['PRICEOFFER_EXCAT'] = Configuration::get('PRICEOFFER_EXCAT');
		$helper->fields_value['PRICEOFFER_EXPROD'] = Configuration::get('PRICEOFFER_EXPROD');
        return $helper->generateForm(array($fields_form));
    }
}
